[infinispan-commits] Infinispan SVN: r228 - trunk/core/src/main/java/org/infinispan/loaders.

infinispan-commits at lists.jboss.org infinispan-commits at lists.jboss.org
Thu May 7 11:43:24 EDT 2009


Author: manik.surtani at jboss.com
Date: 2009-05-07 11:43:24 -0400 (Thu, 07 May 2009)
New Revision: 228

Modified:
   trunk/core/src/main/java/org/infinispan/loaders/LockSupportCacheStore.java
Log:
Typos

Modified: trunk/core/src/main/java/org/infinispan/loaders/LockSupportCacheStore.java
===================================================================
--- trunk/core/src/main/java/org/infinispan/loaders/LockSupportCacheStore.java	2009-05-07 14:27:59 UTC (rev 227)
+++ trunk/core/src/main/java/org/infinispan/loaders/LockSupportCacheStore.java	2009-05-07 15:43:24 UTC (rev 228)
@@ -51,42 +51,42 @@
    /**
     * Release the locks (either read or write).
     */
-   protected void unlock(String key) {
+   protected final void unlock(String key) {
       locks.releaseLock(key);
    }
 
    /**
     * Acquires write lock on the given key.
     */
-   protected void lockForWritting(String key) throws CacheLoaderException {
+   protected final void lockForWriting(String key) throws CacheLoaderException {
       locks.acquireLock(key, true);
    }
 
    /**
     * Acquires read lock on the given key.
     */
-   protected void lockForReading(String key) throws CacheLoaderException {
+   protected final void lockForReading(String key) throws CacheLoaderException {
       locks.acquireLock(key, false);
    }
 
    /**
     * Same as {@link #lockForWritting(String)}, but with 0 timeout.
     */
-   protected boolean immediateLockForWritting(String key) throws CacheLoaderException {
+   protected final boolean immediateLockForWriting(String key) throws CacheLoaderException {
       return locks.acquireLock(key, true, 0);
    }
 
    /**
     * Based on the supplied param, acquires a global read(false) or write (true) lock.
     */
-   protected void acquireGlobalLock(boolean exclusive) throws CacheLoaderException {
+   protected final void acquireGlobalLock(boolean exclusive) throws CacheLoaderException {
       locks.aquireGlobalLock(exclusive, globalLockTimeoutMillis);
    }
 
    /**
     * Based on the supplied param, releases a global read(false) or write (true) lock.
     */
-   protected void releaseGlobalLock(boolean exclusive) {
+   protected final void releaseGlobalLock(boolean exclusive) {
       locks.releaseGlobalLock(exclusive);
    }
 
@@ -122,7 +122,7 @@
       }
 
       String keyHashCode = getLockFromKey(ed.getKey());
-      lockForWritting(keyHashCode);
+      lockForWriting(keyHashCode);
       try {
          storeLockSafe(ed, keyHashCode);
       } finally {
@@ -135,7 +135,7 @@
       if (trace) log.trace("remove(" + key + ")");
       String keyHashCodeStr = getLockFromKey(key);
       try {
-         lockForWritting(keyHashCodeStr);
+         lockForWriting(keyHashCodeStr);
          return removeLockSafe(key, keyHashCodeStr);
       } finally {
          unlock(keyHashCodeStr);
@@ -51,42 +51,42 @@
 
    /**
-    * Same as {@link #lockForWritting(String)}, but with 0 timeout.
+    * Same as {@link #lockForWriting(String)}, but with 0 timeout.
     */




More information about the infinispan-commits mailing list